using System.Drawing;
using PhotinoNET;
using PhotinoNetAbpp.Components;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.
builder.Services.AddRazorComponents()
    .AddInteractiveServerComponents();

builder.WebHost.UseWebRoot("wwwroot").UseStaticWebAssets();
builder.WebHost.UseUrls("http://localhost:5000");

var app = builder.Build();

app.UseHttpsRedirection();
app.UseStaticFiles();
app.UseAntiforgery();
app.MapRazorComponents<App>()
    .AddInteractiveServerRenderMode();

using var webServerCancellation = new CancellationTokenSource();
var webServerTask = app.RunAsync(webServerCancellation.Token);

var window = new PhotinoWindow()
    .SetTitle("Test App")
    .SetUseOsDefaultSize(false)
    .SetSize(new Size(1024, 900))
    .Center()
    .SetResizable(true)
    .Load("http://localhost:5000");

window.WaitForClose();
webServerCancellation.Cancel();
await webServerTask;